summaryrefslogtreecommitdiffstats
path: root/tests/ui/impl-trait/two_tait_defining_each_other2.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/ui/impl-trait/two_tait_defining_each_other2.rs')
-rw-r--r--tests/ui/impl-trait/two_tait_defining_each_other2.rs7
1 files changed, 5 insertions, 2 deletions
diff --git a/tests/ui/impl-trait/two_tait_defining_each_other2.rs b/tests/ui/impl-trait/two_tait_defining_each_other2.rs
index 05b096680..8a79af197 100644
--- a/tests/ui/impl-trait/two_tait_defining_each_other2.rs
+++ b/tests/ui/impl-trait/two_tait_defining_each_other2.rs
@@ -1,13 +1,16 @@
+// revisions: current next
+//[next] compile-flags: -Znext-solver
#![feature(type_alias_impl_trait)]
-type A = impl Foo; //~ ERROR unconstrained opaque type
+type A = impl Foo; //[current]~ ERROR unconstrained opaque type
type B = impl Foo;
trait Foo {}
fn muh(x: A) -> B {
x // B's hidden type is A (opaquely)
//~^ ERROR opaque type's hidden type cannot be another opaque type
}
struct Bar;
@@ -1,13 +1,16 @@
fn muh(x: A) -> B {
x // B's hidden type is A (opaquely)
- //~^ ERROR opaque type's hidden type cannot be another opaque type
+ //[current]~^ ERROR opaque type's hidden type cannot be another opaque type
+ //[next]~^^ ERROR type annotations needed: cannot satisfy `A <: B`
}
struct Bar;